import secureLocalStorage from 'react-secure-storage';

window.addEventListener('beforeunload', () => {
  if (
    !window.performance.getEntriesByType('navigation')
      .map((nav: any) => nav.type).includes('reload')
  ) {
    try {
      localStorage.clear();
      secureLocalStorage.clear();
    } catch (err) {
      throw err;
    }
  }
}, false);

export const loadItem = (
  key: string,
  defaultItem: any = null,
  secure: boolean = false,
) => {
  try {
    if (secure) {
      const secureItem = secureLocalStorage.getItem(key);

      return secureItem ? secureItem : defaultItem;
    }

    const item = localStorage.getItem(key);

    return item ? JSON.parse(item) : defaultItem;
  } catch (err) {
    console.error(err);

    return defaultItem;
  }
};

export const saveItem = (
  key: string,
  item: any,
  secure: boolean = false,
  callback?: any
) => {
  try {
    callback && callback();

    if (secure) {
      return secureLocalStorage.setItem(key, item);
    }

    return localStorage.setItem(key, JSON.stringify(item));
  } catch (err) {
    throw err;
  }
};

export const removeItem = (key: string, secure: boolean = false) => {
  const storage = secure ? secureLocalStorage : localStorage;

  try {
    return storage.removeItem(key);
  } catch (err) {
    throw err;
  }
};
